function fout = Nick_calve(zeta,n_diff,floatspec,parameters)
%fout = calve_phi(zeta,n_diff,floatspec,parameters)
%   Computes fraction of floatation thickness r*H_g attained by ice at the
%   calving front as a function of zeta = Lambda/H_g
%   Input arguemnts
%       zeta:   Nick et al (2010) dimensionless calving parameter
%       n_diff: order of differentiation
%       floatspec:  Specifies whether formula for floating ice ('floating')
%               or grounded ice ('grounded') should be used
%       parameters: parameter structure, most contain parameters.model.r =
%               ratio of ice to water density

r = parameters.model.r;

switch n_diff
    case 0
    switch floatspec
        case 'grounded'
            fout = 1 + (1-r)/r*zeta + sqrt((1+(1-r)/r*zeta)^2-1/r);
        case 'floating'
            fout = 2*zeta/r;
    end
    case 1
    switch floatspec
        case 'grounded'
            fout = (1-r)/r*(1 + (1+(1-r)/r*zeta)/sqrt((1+(1-r)/r*zeta)^2-1/r));
        case 'floating'
            fout = 2/r;
    end
end

end

