function [dQ_gdH_g_0,dQ_gdW_0,dQ_gdC_0,dQ_gdM_0,dQ_gdLambda_0] = flux_derivatives(fin,parameters)
%fout = flux_derivatives(fin)
%   Takes output from solving for roots of boundary_layer_constraint_v1 and
%   computes derivatives of solution Q_g with respect to H_g_0, W_0, C_0,
%   M_0, Lambda_0
%
%   input arguments:
%       fin:    a 2-by-npts or 3-by-npts array of column vectors [Q_g;indvar]
%               or [Q_g;xi_f;indvar], the column vector format depending on
%               parameters.indvar as in boundary_layer_constraint_v1 (see
%               documentation for boundary_layer_constraint_v1.m)
%       paranmeters:    same parameter structure as used in
%               boundary_layer_constraint_v1  (see
%               documentation for boundary_layer_constraint_v1.m)
%   output arguments:
%       dQ_gdH_g_0,dQ_gdW_0,dQ_gdC_0,dQ_gdM_0,dQ_gdLambda_0: derivatives of
%               each Q_g in fin with respect to the parameter indicated by
%               the variable name. See boundary_layer_shoot_v1 for details on
%               how Q_g is defined as a function of these parameters.

%length of array
npts = length(fin(1,:));

%initialize output
dQ_gdH_g_0 = zeros(npts,1);
dQ_gdW_0 = zeros(npts,1);
dQ_gdC_0 = zeros(npts,1);
dQ_gdM_0 = zeros(npts,1);
dQ_gdLambda_0 = zeros(npts,1);

%loop through solution vectors
for ii=1:npts
    J = boundary_layer_sensitivity(fin(:,ii),parameters);
    switch parameters.calving_type
        case 'melt limit'
            Jaux = J(1,:)*J(2,2)-J(2,:)*J(1,2);
            dQ_gdH_g_0(ii) = -Jaux(3)/Jaux(1);
            dQ_gdW_0(ii) = -Jaux(4)/Jaux(1);
            dQ_gdC_0(ii) = -Jaux(5)/Jaux(1);
            dQ_gdM_0(ii) = -Jaux(6)/Jaux(1);
            dQ_gdLambda_0(ii) = -Jaux(7)/Jaux(1);
        otherwise
            dQ_gdH_g_0(ii) = -J(2)/J(1);
            dQ_gdW_0(ii) = -J(3)/J(1);
            dQ_gdC_0(ii) = -J(4)/J(1);
            dQ_gdM_0(ii) = -J(5)/J(1);
            dQ_gdLambda_0(ii) = -J(6)/J(1);
    end
end

